package App::zen;

our $VERSION = 0.07;

=head1 NAME

App::zen - A literate programming tool using markdown extension.

=head1 DESCRIPTION

Zen allows you to write documentation with code side by side.

=head1 AUTHOR

Chaoji Li<lichaoji@gmail.com>

=head1 LICENSE

perl

=cut
1;
